@@ -165,7 +165,7 @@ BatchtoolsParam <-
         template = batchtoolsTemplate(cluster),
         stop.on.error = TRUE,
         progressbar=FALSE, RNGseed = NA_integer_,
-        timeout= 30L * 24L * 60L * 60L, exportglobals=TRUE,
+        timeout= WORKER_TIMEOUT, exportglobals=TRUE,
         log=FALSE, logdir=NA_character_,
         resultdir=NA_character_, jobname = "BPJOB"
     )
@@ -346,7 +346,8 @@ setMethod("bpstop", "BatchtoolsParam",
 ###
 
 setMethod("bplapply", c("ANY", "BatchtoolsParam"),
-          function(X, FUN, ..., BPREDO = list(), BPPARAM=bpparam())
+          function(X, FUN, ..., BPREDO = list(),
+                   BPPARAM=bpparam(), BPOPTIONS = bpoptions())
 {
     FUN <- match.fun(FUN)
 
@@ -358,7 +359,7 @@ setMethod("bplapply", c("ANY", "BatchtoolsParam"),
         X <- as.list(X)
 
     idx <- .redo_index(X, BPREDO)
-    if (any(idx))
+    if (length(idx))
         X <- X[idx]
     nms <- names(X)
 
@@ -386,9 +387,15 @@ setMethod("bplapply", c("ANY", "BatchtoolsParam"),
 
     registry <- BPPARAM$registry
 
+    OPTIONS <- .workerOptions(
+        log = bplog(BPPARAM),
+        stop.on.error = bpstopOnError(BPPARAM),
+        timeout = bptimeout(BPPARAM),
+        exportglobals = bpexportglobals(BPPARAM)
+    )
+
     FUN <- .composeTry(
-        FUN, bplog(BPPARAM), bpstopOnError(BPPARAM),
-        timeout=bptimeout(BPPARAM), exportglobals=bpexportglobals(BPPARAM)
+        FUN, OPTIONS = OPTIONS, SEED = NULL
     )
 
     ##  Make registry / map / submit / wait / load
@@ -401,7 +408,7 @@ setMethod("bplapply", c("ANY", "BatchtoolsParam"),
         ids = ids, resources = .bpresources(BPPARAM), reg = registry
     )
     batchtools::waitForJobs(
-        ids = ids, reg = registry, timeout = bptimeout(BPPARAM),
+        ids = ids, reg = registry, timeout = .batch_bptimeout(BPPARAM),
         stop.on.error = bpstopOnError(BPPARAM)
     )
     res <- batchtools::reduceResultsList(ids = ids, reg = registry)
@@ -410,7 +417,8 @@ setMethod("bplapply", c("ANY", "BatchtoolsParam"),
     if (bplog(BPPARAM) && !is.na(bplogdir(BPPARAM))) {
         logs <- file.path(.bpregistryargs(BPPARAM)$file.dir, "logs")
         ## Create log dir
-        dir.create(bplogdir(BPPARAM))
+        if (!file.exists(bplogdir(BPPARAM)))
+            dir.create(bplogdir(BPPARAM))
         ## Recursive copy logs
         file.copy(logs, bplogdir(BPPARAM) , recursive=TRUE, overwrite=TRUE)
     }
@@ -431,12 +439,12 @@ setMethod("bplapply", c("ANY", "BatchtoolsParam"),
     if (!is.null(res))
         names(res) <- nms
 
-    if (any(idx)) {
+    if (length(BPREDO) && length(idx)) {
         BPREDO[idx] <- res
         res <- BPREDO
     }
 
-    if (!all(bpok(res)))
+    if (!.bpallok(res))
         stop(.error_bplist(res))
 
     res
@@ -445,7 +453,7 @@ setMethod("bplapply", c("ANY", "BatchtoolsParam"),
 
 setMethod("bpiterate", c("ANY", "ANY", "BatchtoolsParam"),
     function(ITER, FUN, ..., REDUCE, init, reduce.in.order=FALSE,
-             BPPARAM=bpparam())
+             BPREDO = list(), BPPARAM=bpparam(), BPOPTIONS=bpoptions())
 {
     ITER <- match.fun(ITER)
     FUN <- match.fun(FUN)
@@ -460,20 +468,30 @@ setMethod("bpiterate", c("ANY", "ANY", "BatchtoolsParam"),
     if (!bpschedule(BPPARAM) || bpnworkers(BPPARAM) == 1L) {
         param <- as(BPPARAM, "SerialParam")
         return(
-            bpiterate(ITER, FUN, ..., REDUCE=REDUCE, init=init, BPPARAM=param)
+            bpiterate(ITER, FUN, ..., REDUCE=REDUCE, init=init,
+                      BPREDO = BPREDO, BPPARAM=param, BPOPTIONS=BPOPTIONS)
         )
     }
 
+    if (!identical(BPREDO, list()))
+        stop("BPREDO is not supported by the BatchtoolsParam yet!")
+
     ## start / stop cluster
     if (!bpisup(BPPARAM)) {
         bpstart(BPPARAM)
         on.exit(bpstop(BPPARAM))
     }
 
+    OPTIONS <- .workerOptions(
+        log = bplog(BPPARAM),
+        stop.on.error = bpstopOnError(BPPARAM),
+        timeout = bptimeout(BPPARAM),
+        exportglobals = bpexportglobals(BPPARAM)
+    )
+
     ## composeTry
     FUN <- .composeTry(
-        FUN, bplog(BPPARAM), bpstopOnError(BPPARAM),
-        timeout=bptimeout(BPPARAM), exportglobals=bpexportglobals(BPPARAM)
+        FUN, OPTIONS = OPTIONS, SEED = NULL
     )
 
     FUN <- .composeBatchtools(FUN)
