@@ -6,7 +6,7 @@ multicoreWorkers <- function()
     .snowCores("multicore")
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Constructor 
+### Constructor
 ###
 
 .MulticoreParam_prototype <- .SnowParam_prototype
@@ -17,13 +17,14 @@ multicoreWorkers <- function()
     methods=list()
 )
 
-MulticoreParam <- function(workers=multicoreWorkers(), tasks=0L,  
-        stop.on.error=TRUE, 
-        progressbar=FALSE, RNGseed=NULL, timeout= 30L * 24L * 60L * 60L,
+MulticoreParam <- function(workers=multicoreWorkers(), tasks=0L,
+        stop.on.error=TRUE,
+        progressbar=FALSE, RNGseed=NULL, timeout= WORKER_TIMEOUT,
         exportglobals=TRUE,
         log=FALSE, threshold="INFO", logdir=NA_character_,
         resultdir=NA_character_, jobname = "BPJOB",
         force.GC = TRUE,
+        fallback = TRUE,
         manager.hostname=NA_character_, manager.port=NA_integer_, ...)
 {
     if (.Platform$OS.type == "windows") {
@@ -32,7 +33,7 @@ MulticoreParam <- function(workers=multicoreWorkers(), tasks=0L,
     }
 
     if (progressbar && missing(tasks))
-        tasks <- .Machine$integer.max
+        tasks <- TASKS_MAXIMUM
 
     clusterargs <- c(list(spec=workers, type="FORK"), list(...))
 
@@ -54,15 +55,17 @@ MulticoreParam <- function(workers=multicoreWorkers(), tasks=0L,
     prototype <- .prototype_update(
         .MulticoreParam_prototype,
         .clusterargs=clusterargs, cluster=.NULLcluster(),
-        .controlled=TRUE, workers=as.integer(workers), 
+        .controlled=TRUE, workers=as.integer(workers),
         tasks=as.integer(tasks),
-        stop.on.error=stop.on.error, 
-        progressbar=progressbar, 
+        stop.on.error=stop.on.error,
+        progressbar=progressbar,
         RNGseed=RNGseed, timeout=as.integer(timeout),
         exportglobals=exportglobals,
+        exportvariables=FALSE,
         log=log, threshold=threshold,
         logdir=logdir, resultdir=resultdir, jobname=jobname,
         force.GC = force.GC,
+        fallback = fallback,
         hostname=manager.hostname, port=manager.port,
         ...
     )
@@ -85,16 +88,16 @@ setReplaceMethod("bpworkers", c("MulticoreParam", "numeric"),
         stop(
             "'value' exceeds ", max, " available workers; see ?multicoreWorkers"
         )
- 
-    x$workers <- value 
-    x$.clusterargs$spec <- value 
-    x 
+
+    x$workers <- value
+    x$.clusterargs$spec <- value
+    x
 })
 
 setMethod("bpschedule", "MulticoreParam",
     function(x)
 {
-    if (.Platform$OS.type == "windows") 
+    if (.Platform$OS.type == "windows")
         FALSE
     else
         TRUE
