@@ -1,5 +1,7 @@
-test_BatchJobsParam <- 
-    function() 
+message("Testing BatchJobsParam")
+
+test_BatchJobsParam <-
+    function()
 {
     param <- BatchJobsParam(2, progressbar=FALSE, cleanup=TRUE)
     checkEquals(as.list(sqrt(1:3)), bplapply(1:3, sqrt, BPPARAM=param))
@@ -10,5 +12,5 @@ test_BatchJobsParam <-
         bplapply(X, sqrt, BPPARAM=param)
     }, error=identity)
     checkTrue(is(res, "bplist_error"))
-    checkTrue(is(attr(res, "result")[[2]], "remote_error"))
+    checkTrue(is(bpresult(res)[[2]], "remote_error"))
 }
