@@ -1,8 +1,11 @@
+message("Testing bplapply")
+
 quiet <- suppressWarnings
 
 test_bplapply_Params <- function()
 {
-    doParallel::registerDoParallel(2)
+    cl <- parallel::makeCluster(2)
+    doParallel::registerDoParallel(cl)
     params <- list(serial=SerialParam(),
                    snow=SnowParam(2),
                    dopar=DoparParam(),
@@ -31,15 +34,16 @@ test_bplapply_Params <- function()
     checkTrue(all.equal(current[[2]], list(c("A", "B"), 1, 10)))
 
     ## clean up
-    env <- foreach:::.foreachGlobals
-    rm(list=ls(name=env), pos=env)
+    foreach::registerDoSEQ()
+    parallel::stopCluster(cl)
     closeAllConnections()
     TRUE
 }
 
 test_bplapply_symbols <- function()
 {
-    doParallel::registerDoParallel(2)
+    cl <- parallel::makeCluster(2)
+    doParallel::registerDoParallel(cl)
     params <- list(serial=SerialParam(),
                    snow=SnowParam(2),
                    dopar=DoparParam()
@@ -56,8 +60,8 @@ test_bplapply_symbols <- function()
     }
 
     ## clean up
-    env <- foreach:::.foreachGlobals
-    rm(list=ls(name=env), pos=env)
+    foreach::registerDoSEQ()
+    parallel::stopCluster(cl)
     closeAllConnections()
     TRUE
 }
