@@ -1,6 +1,9 @@
+message("Testing bpvectorize")
+
 test_bpvectorize_Params <- function()
 {
-    doParallel::registerDoParallel(2)
+    cl <- parallel::makeCluster(2)
+    doParallel::registerDoParallel(cl)
     params <- list(serial=SerialParam(),
                    snow=SnowParam(2),
                    batchjobs=BatchJobsParam(2, progressbar=FALSE),
@@ -16,8 +19,8 @@ test_bpvectorize_Params <- function()
     }
 
     ## clean up
-    env <- foreach:::.foreachGlobals
-    rm(list=ls(name=env), pos=env)
+    foreach::registerDoSEQ()
+    parallel::stopCluster(cl)
     closeAllConnections()
     TRUE
 }
